"""
@author: luojunhui
"""
import asyncio

from applications.schedule import re_search_videos


class ReSearchDeal(object):
    """
    重新搜索逻辑
    obj = {
        "ori_title": params['title'],
        "content_title": params['kimi_summary'],
        "content_keys": params['kimi_keys'],
        "trace_id": params['trace_id']
    }
    """

    def __init__(self, params):
        self.gh_id = None
        self.trace_id = None
        self.kimi_keys = None
        self.kimi_summary = None
        self.title = None
        self.params = params

    def check_params(self):
        """
        check params
        :return:
        """
        try:
            self.title = self.params['title']
            self.kimi_summary = self.params['kimi_summary']
            self.kimi_keys = self.params['kimi_keys']
            self.trace_id = self.params['trace_id']
            self.gh_id = self.params['ghId']
            return None
        except AttributeError as e:
            result = {
                "status": "fail",
                "code": 1,
                "message": str(e),
                "info": "params check error"
            }
            return result
        
    async def deal(self):
        """
        research function deal
        :return: 
        """
        params_error = self.check_params()
        if params_error:
            return params_error
        else:
            try:
                asyncio.ensure_future(
                    re_search_videos(
                        self.params,
                        self.trace_id,
                        self.gh_id)
                )
                res = {
                    "status": "success",
                    "code": 0,
                    "traceId": self.trace_id
                }
                return res
            except Exception as e:
                res = {
                    "status": "fail",
                    "code": 1,
                    "message": str(e)
                }
                return res
            
